#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis {
  [StorableClass]
  [Item("ClassificationProblem", "")]
  [Creatable]
  public class ClassificationProblem : DataAnalysisProblem<IClassificationProblemData>,
    IClassificationProblem {
    private const string ProblemDataParameterName = "ProblemData";
    public ClassificationProblem(ClassificationProblem original, Cloner cloner)
      : base(original, cloner) {
      RegisterEventHandlers();
    }
    [StorableConstructor]
    public ClassificationProblem(bool deserializing) : base(deserializing) { }
    public ClassificationProblem()
      : base() {
      Parameters.Add(new ValueParameter<IClassificationProblemData>(ProblemDataParameterName, "", new ClassificationProblemData()));
      RegisterEventHandlers();
    }

    [StorableHook(HookType.AfterDeserialization)]
    private void AfterDeserialization() {
      RegisterEventHandlers();
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ClassificationProblem(this, cloner);
    }

    private void RegisterEventHandlers() {
      ProblemDataParameter.Value.Changed += new EventHandler(Value_Changed);
    }

    #region event propagation
    private void Value_Changed(object sender, EventArgs e) {
      //OnReset();
    }
    #endregion
  }
}
